pub unsafe fn set_bits25(
ptr: *mut u8,
first_bit: usize,
value: u32,
len_mask: u32,
)Expand description
Write desired number, at most 25 lowest value bits to ptr, beginning from first_bit, using bit-or operation.
Before write, appropriate fragment of buffer is zeroed by bit-andn with len_mask
(which should be of type 0..01..1, with desired number of bit ones).
The most significant bits of value should be zeros.